@@ -5,7 +5,7 @@ from PySide.QtCore import *
 from PySide.QtGui import *
 
 # Some global variables
-FceuGuiVersion = "0.0.1-5"
+FceuGuiVersion = "0.0.1-6"
 CommentChar = '#'
 OptionChar =  ' '
 Home = os.path.expanduser("~")
@@ -601,7 +601,7 @@ class pathWindow(QDialog):
 	self.close()
 	os.system('run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications  \
 	           /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint \
-	           string:"Use SAVE button to save it!"')
+	           string:"Use SAVE button in config screen to save it!"')
 
     def on_rom2_homebutton_clicked(self):
 	global RomPath2
@@ -609,7 +609,7 @@ class pathWindow(QDialog):
 	self.close()
 	os.system('run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications  \
 	           /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint \
-	           string:"Use SAVE button to save it!"')
+	           string:"Use SAVE button in config screen to save it!"')
 
     def on_rom_rootbutton_clicked(self):
 	global RomPath
@@ -617,15 +617,15 @@ class pathWindow(QDialog):
 	self.close()
 	os.system('run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications  \
 	           /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint \
-	           string:"Use SAVE button to save it!"')
+	           string:"Use SAVE button in config screen to save it!"')
 
     def on_rom2_rootbutton_clicked(self):
-	global RomPath
+	global RomPath2
 	RomPath2 = QFileDialog.getExistingDirectory(self, 'Choose directory', '/media')
 	self.close()
 	os.system('run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications  \
 	           /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint \
-	           string:"Use SAVE button to save it!"')
+	           string:"Use SAVE button in config screen to save it!"')
 
     def on_exec_button_clicked(self):
 	global ExecPath
